MCPcopy Create free account
hub / github.com/ComputationalRobotics/XM-code / ScaMatkernel

Function ScaMatkernel

XM/include/Dense/scalar.h:10–15  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

8// scalr multi matrix kernal
9template <typename T>
10__global__ void ScaMatkernel(T *A, T scalar, size_l n) {
11 size_l idx = blockIdx.x * blockDim.x + threadIdx.x;
12 if (idx < n) {
13 A[idx] *= scalar;
14 }
15}
16
17// function for dense tensor
18template <typename T>

Callers

nothing calls this directly

Calls

no outgoing calls

Tested by

no test coverage detected